Method: Dry::System::Config::ComponentDirs#namespaces
- Defined in:
- lib/dry/system/config/component_dirs.rb
#namespaces ⇒ Namespaces
Returns the default configured namespaces for all added component dirs
Allows namespaces to added on the returned object via Namespaces#add.
|
|
# File 'lib/dry/system/config/component_dirs.rb', line 67
|